@@ -1,5 +1,5 @@
 package HackaMol::AtomGroupRole;
-$HackaMol::AtomGroupRole::VERSION = '0.014';
+$HackaMol::AtomGroupRole::VERSION = '0.015';
 #ABSTRACT: Role for a group of atoms
 use Moose::Role;
 use Carp;
@@ -312,8 +312,13 @@ sub _open_file_unless_fh {
     my $fh = \*STDOUT;   # default to standard out
                          # if argument is passed, check if filehandle
     if ( defined($file) ) {
-        if ( ref($file) and reftype($file) eq "GLOB" ) {
-            $fh = $file;
+        if ( ref($file) ) {
+            if (reftype($file) eq "GLOB"){
+              $fh = $file;
+            }
+            else {
+              croak "trying write to reference that is not a GLOB";
+            }
         }
         else {
             carp "overwrite $file" if ( -e $file );
@@ -339,7 +344,7 @@ HackaMol::AtomGroupRole - Role for a group of atoms
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 SYNOPSIS
 
